"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const t = require("@babel/types");
const plugin_syntax_jsx_1 = require("@babel/plugin-syntax-jsx");
const md5 = require("md5");
const getFilenameFromPath = (filePath) => {
    const parts = filePath.split('/');
    return parts[parts.length - 1].split('?')[0];
};
const forPlugin = (path, stats) => {
    let { include: includeRegExp } = stats.opts;
    if (!includeRegExp) {
        includeRegExp = /\.scoped\.(sa|sc|c)ss$/;
    }
    const filename = getFilenameFromPath(path.node.source.value);
    return filename.match(new RegExp(includeRegExp));
};
const hasHashKey = (node, key) => {
    return ~node.attributes.findIndex((item) => t.isJSXAttribute(item) &&
        t.isJSXIdentifier(item.name) &&
        item.name.name === key);
};
function default_1() {
    const computedHash = {};
    let lastHash = '';
    const computeHash = (filePath) => {
        if (computedHash[filePath]) {
            return computedHash[filePath];
        }
        const filename = getFilenameFromPath(filePath);
        const hash = md5(filename + lastHash).substr(0, 8);
        computedHash[filePath] = hash;
        lastHash = hash;
        return hash;
    };
    return {
        name: 'babel-plugin-vue-jsx-scoped-css',
        inherits: plugin_syntax_jsx_1.default,
        pre() {
            this.hasScopedCss = false;
        },
        visitor: {
            ImportDeclaration(path, stats) {
                if (!forPlugin(path, stats)) {
                    return;
                }
                this.hasScopedCss = true;
                const hash = computeHash(stats.file.opts.filename);
                path.node.source.value = `${path.node.source.value}?scopeId=${hash}`;
            },
            JSXElement(path, stats) {
                const self = this;
                path.parentPath.traverse({
                    JSXOpeningElement(p) {
                        if (!self.hasScopedCss ||
                            p.node.name.type === 'JSXMemberExpression') {
                            return;
                        }
                        const hash = computeHash(stats.file.opts.filename);
                        const hashAttr = `data-v-${hash}`;
                        !hasHashKey(p.node, hashAttr) &&
                            p.node.attributes.push(t.jsxAttribute(t.jsxIdentifier(hashAttr), t.jsxExpressionContainer(t.stringLiteral(''))));
                    }
                });
            }
        }
    };
}
exports.default = default_1;
//# sourceMappingURL=index.js.map